#!/bin/bash
if [ $# -ne 3 ]; then
    echo "Usage: $0 <file_path>"
    exit 1
fi
current_develop(){
    cmdline=$(cat /proc/cmdline)
	ostree_param=$(echo $cmdline | grep -o 'ostree=[^ ]*')

	if [ -z "$ostree_param" ]; then
    	echo "ostree= 引导项未找到"
    	exit 1
	fi
	# 获取 ostree= 参数的值（即文件路径）
	ostree_path=$(echo $ostree_param | cut -d'=' -f2)
	# 使用 readlink 获取真实文件链接
	real_path=$(readlink -f $ostree_path)

    file_name=$(basename "$real_path")  
    commit="${file_name%.*}"     
    echo "$commit"               

    if [ $? -ne 0 ]; then
    	echo "无法解析 ostree 路径: $ostree_path"
    	exit 1
    else
        echo "获取到当前的部署路径$real_path"
        etc_copy="${real_path}/usr${3}"
        var_copy="${real_path}${3}"
        if [ "$1" == "etc" ]; then
            if [ "$2" == "install" ];then
                if [ -e "$3" ]; then
                    echo "File exists, performing restore $3..."
                    diff_result=$(diff "$3" "$etc_copy")
                    # 检查是否有差异
                    if [ -z "$diff_result" ]; then
                        echo "$3没有差异"
                    else
                        echo "$3有差异"
                        if [ -d "$3" ];then
                            rsync -r -ac --inplace --xattrs --links $etc_copy/* $3
                        else
                            rsync -r -ac --inplace --xattrs --links $etc_copy $3
                        fi
                    fi
                else
                    if [ -d "$etc_copy" ];then #判断是文件还是目录
                        mkdir -p $3
                        rsync -r -ac --inplace --xattrs --links $etc_copy/* $3
                    else
                        rsync -r -ac --inplace --xattrs --links $etc_copy $3
                    fi
                fi
                if  sed -i "\|${3}</path>| {n;/\s*<status>completed<\/status>/d}" "/etc/ostree/ost-ex.d/ostree_coredata.xml"; then
                    echo "成功删除 <status>completed</status> 从 ${3} 节点"
                else
                    echo "错误：无法修改 XML 文件"
                    exit 1
                fi
            else
                if [ -e "$3" ]; then
                    echo "File exists, performing restore $3..."
                    diff_result=$(diff "$3" "$etc_copy")
                    # 检查是否有差异
                    if [ -z "$diff_result" ]; then
                        echo "$3没有差异"
                    else
                        echo "$3有差异"
                        ostree checkout --subpath=/usr${3} --union -C $commit $3
                        if [ $? -ne 0 ]; then
                            if [ -d "$3" ];then
                            rsync -r -ac --inplace --xattrs --links $etc_copy/* $3
                            else
                            rsync -r -ac --inplace --xattrs --links $etc_copy $3
                            fi
                        fi
                    fi
                else
                    ostree checkout --subpath=/usr${3} --union -C $commit $3
                    if [ $? -ne 0 ]; then
                        if [ -d "$3" ];then
                            mkdir -p $3
                            rsync -r -ac --inplace --xattrs --links $etc_copy/* $3
                        else
                            rsync -r -ac --inplace --xattrs --links $etc_copy $3
                        fi
                    fi
                fi

            fi
        fi
        if [ "$1" == "var" ]; then
            if [ "$2" == "install" ];then
                if [ -e "$3" ]; then
                    echo "File exists, performing checkout..."
                    diff_result=$(diff "$3" "$var_copy")
                # 检查是否有差异
                    if [ -z "$diff_result" ]; then
                        echo "$3没有差异"
                    else
                        echo "$3有差异"
                        if [ -d "$3" ];then
                            rsync -r -ac --inplace --xattrs --links $var_copy/* $3
                        else
                            rsync -r -ac --inplace --xattrs --links $var_copy $3
                        fi
                    fi
                else
                    if [ -d "$var_copy" ];then #判断是文件还是目录
                        mkdir -p $3
                        rsync -r -ac --inplace --xattrs --links $var_copy/* $3
                    else
                        rsync -r -ac --inplace --xattrs --links $var_copy $3
                    fi
                fi
            else
                if [ -e "$3" ]; then
                    echo "File exists, performing checkout..."
                    diff_result=$(diff "$3" "$var_copy")
                # 检查是否有差异
                    if [ -z "$diff_result" ]; then
                        echo "$3没有差异"
                    else
                        echo "$3有差异"
                        ostree checkout --subpath=/usr${3} --union -C $commit $3
                        if [ $? -ne 0 ]; then
                            if [ -d "$3" ];then
                            rsync -r -ac --inplace --xattrs --links $var_copy/* $3
                            else
                            rsync -r -ac --inplace --xattrs --links $var_copy $3
                            fi
                        fi
                    fi
                else
                    ostree checkout --subpath=/usr${3} --union -C $commit $3
                    if [ $? -ne 0 ]; then
                        if [ -d "$3" ];then
                            mkdir -p $3
                            rsync -r -ac --inplace --xattrs --links $var_copy/* $3
                        else
                            rsync -r -ac --inplace --xattrs --links $var_copy $3
                        fi
                    fi
                fi

            fi
        fi
    fi
}

path_type="$1"
type="$2"
path="$3"
echo "coredata restore $1 $2 $3"
current_develop $path_type $type $path
